%global pkg pmd
%global pkgname pmd-emacs

%if %($(pkg-config emacs) ; echo $?)
%global emacs_version  22.1
%global emacs_lispdir  %{_datadir}/emacs/site-lisp
%global emacs_startdir %{_datadir}/emacs/site-lisp/site-start.d
%else
%global emacs_version  %(pkg-config emacs --modversion)
%global emacs_lispdir  %(pkg-config emacs --variable sitepkglispdir)
%global emacs_startdir %(pkg-config emacs --variable sitestartdir)
%endif

%if %($(pkg-config xemacs) ; echo $?)
%global xemacs_version  21.5
%global xemacs_lispdir  %{_datadir}/xemacs/site-packages/lisp
%global xemacs_startdir %{_datadir}/xemacs/site-packages/lisp/site-start.d
%else
%global xemacs_version  %(pkg-config xemacs --modversion)
%global xemacs_lispdir  %(pkg-config xemacs --variable sitepkglispdir)
%global xemacs_startdir %(pkg-config xemacs --variable sitestartdir)
%endif

Name:           emacs-common-%{pkg}
Version:        0.6
Release:        2%{?dist}
Summary:        An interface to PMD for Emacs

Group:          Development/Tools
License:        GPLv2+
URL:            http://pmd.sourceforge.net/
Source0:        http://downloads.sourceforge.net/pmd/pmd-emacs-%{version}.zip
Source1:        pmd.el
# This patch has not been sent upstream, since it is (mostly) Fedora specific.
# It does the following:
# - Adds (require 'compile) so that compile-mode related functions and
#   variables are defined.
# - Changes the default path to the Java binary to /usr/bin/java.
# - Removes the pmd-home variable, since it is used by code that assumes a
#   directory structure that does not exist in the Fedora PMD package.
# - Replaces the pmd-xemacsp variables with (featurep 'xemacs).  The latter
#   form is recognized by the Emacs byte compiler, and results in fewer
#   warnings and more efficient code than the former.
# - Changes the definitions of pmd-classpath and pmd-jar to match the locations
#   of PMD-related JAR files on Fedora.
# - On Emacs, uses compilation-start instead of the obsolete compile-internal.
Patch0:         pmd-emacs-0.6.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildArch:      noarch
BuildRequires:  emacs emacs-el xemacs xemacs-devel xemacs-packages-extra

%description
%{pkgname} supports the invocation of PMD from within (X)Emacs.  Specifically,
it supplies functions pmd-current-buffer and pmd-current-dir, and enables
parsing of the resulting list of PMD complaints so that, for example,
next-error will walk through the list correctly.

This package contains the files common to both the GNU Emacs and XEmacs
%{pkgname} packages.


%package -n emacs-%{pkg}
Summary:        Compiled elisp files to run %{pkgname} under GNU Emacs
Group:          Development/Tools
Requires:       emacs(bin) >= %{emacs_version}
Requires:       emacs-common-%{pkg} = %{version}-%{release}
Requires:       pmd

%description -n emacs-%{pkg}
This package contains the byte compiled elisp packages to run %{pkgname} with
GNU Emacs.

%package -n emacs-%{pkg}-el
Summary:        Elisp source files for %{pkgname} under GNU Emacs
Group:          Development/Tools
Requires:       emacs-%{pkg} = %{version}-%{release}

%description -n emacs-%{pkg}-el
This package contains the elisp source files for %{pkgname} under GNU Emacs.
You do not need to install this package to run %{pkgname}.  Install the
emacs-%{pkg} package to use %{pkgname} with GNU Emacs.


%package -n xemacs-%{pkg}
Summary:        Compiled elisp files to run %{pkgname} under XEmacs
Group:          Development/Tools
Requires:       xemacs(bin) >= %{xemacs_version}
Requires:       xemacs-packages-extra
Requires:       emacs-common-%{pkg} = %{version}-%{release}
Requires:       pmd

%description -n xemacs-%{pkg}
This package contains the byte compiled elisp packages to run %{pkgname} with
XEmacs.

%package -n xemacs-%{pkg}-el
Summary:        Elisp source files for %{pkgname} under XEmacs
Group:          Development/Tools
Requires:       xemacs-%{pkg} = %{version}-%{release}

%description -n xemacs-%{pkg}-el
This package contains the elisp source files for %{pkgname} under XEmacs.
You do not need to install this package to run %{pkgname}.  Install the
xemacs-%{pkg} package to use %{pkgname} with XEmacs.


%prep
%setup -q -n %{pkgname}-%{version}
%patch0 -p1
chmod a-x pmd.el


%build


%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{emacs_lispdir}/%{pkg}
mkdir -p $RPM_BUILD_ROOT%{emacs_startdir}
emacs -batch -no-site-file -f batch-byte-compile pmd.el
cp -p pmd.el* $RPM_BUILD_ROOT%{emacs_lispdir}/%{pkg}
cp -p %{SOURCE1} $RPM_BUILD_ROOT%{emacs_startdir}

mkdir -p $RPM_BUILD_ROOT%{xemacs_lispdir}/%{pkg}
mkdir -p $RPM_BUILD_ROOT%{xemacs_startdir}
rm -f pmd.elc
xemacs -batch -no-site-file -f batch-byte-compile pmd.el
cp -p pmd.el* $RPM_BUILD_ROOT%{xemacs_lispdir}/%{pkg}
cp -p %{SOURCE1} $RPM_BUILD_ROOT%{xemacs_startdir}


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%doc CHANGELOG INSTALL LICENSE.txt

%files -n emacs-%{pkg}
%defattr(-,root,root,-)
%dir %{emacs_lispdir}/%{pkg}
%{emacs_lispdir}/%{pkg}/%{pkg}.elc
%{emacs_startdir}/%{pkg}.el

%files -n emacs-%{pkg}-el
%defattr(-,root,root,-)
%{emacs_lispdir}/%{pkg}/%{pkg}.el

%files -n xemacs-%{pkg}
%defattr(-,root,root,-)
%dir %{xemacs_lispdir}/%{pkg}
%{xemacs_lispdir}/%{pkg}/%{pkg}.elc
%{xemacs_startdir}/%{pkg}.el

%files -n xemacs-%{pkg}-el
%defattr(-,root,root,-)
%{xemacs_lispdir}/%{pkg}/%{pkg}.el


%changelog
* Fri Aug 21 2009 Jerry James <loganjerry@gmail.com> - 0.6-2
- Package structure and naming cleanups to adhere to Fedora guidelines

* Wed Jan 21 2009 Jerry James <loganjerry@gmail.com> - 0.6-1
- Initial package
